arcbox-api 0.0.1-alpha.1

API server for ArcBox (gRPC + REST)
docs.rs failed to build arcbox-api-0.0.1-alpha.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

arcbox-api

API server for ArcBox.

Provides multiple API interfaces:

  • gRPC API: High-performance native API (tonic)
  • Docker API: Docker CLI compatibility (arcbox-docker)

Architecture

┌─────────────────────────────────────────────────┐
│                   arcbox-api                    │
│                                                 │
│  ┌─────────────┐         ┌─────────────────┐  │
│  │   gRPC      │         │   Docker API    │  │
│  │   Server    │         │   (arcbox-docker)│  │
│  └──────┬──────┘         └────────┬────────┘  │
│         │                         │           │
│         └────────────┬────────────┘           │
│                      ▼                        │
│              ┌─────────────┐                  │
│              │ arcbox-core │                  │
│              └─────────────┘                  │
└─────────────────────────────────────────────────┘